@@ -1,4 +1,6 @@
-require 'sentry/sidekiq/context_filter'
+# frozen_string_literal: true
+
+require "sentry/sidekiq/context_filter"
 
 module Sentry
   module Sidekiq
@@ -29,6 +31,22 @@ module Sentry
           end
         end
 
+        # See if we want to ignore jobs that have dead: false
+        return if Sentry.configuration.sidekiq.report_only_dead_jobs && context.dig(:job, "dead") == false
+
+        # Check if the retry count is below the attempt_threshold
+        attempt_threshold = context.dig(:job, "attempt_threshold")
+        if attempt_threshold && retryable?(context)
+          attempt_threshold = attempt_threshold.to_i
+          retry_count = context.dig(:job, "retry_count")
+          # attempt 1 - retry_count is nil
+          # attempt 2 - this is your first retry so retry_count is 0
+          # attempt 3 - you have retried once, retry_count is 1
+          attempt = retry_count.nil? ? 1 : retry_count.to_i + 2
+
+          return if attempt < attempt_threshold
+        end
+
         Sentry::Sidekiq.capture_exception(
           ex,
           contexts: { sidekiq: context_filter.filtered },
